@@ -1,21 +1,31 @@
 # -*- coding: utf-8 -*-
 
 import martian
-import zope.component
 import grokcore.view
-import grokcore.component
+import zope.component
 
+from grokcore.view.meta.views import TemplateGrokker
 from megrok.pagetemplate.components import PageTemplate
 from zope.pagetemplate.interfaces import IPageTemplate
 from zope.publisher.interfaces.browser import IDefaultBrowserLayer
 
 
+class PageTemplateTemplateGrokker(TemplateGrokker):
+    martian.component(PageTemplate)
+
+    def has_render(self, factory):
+        return False
+
+    def has_no_render(self, factory):
+        return True
+
+
 class PageTemplateGrokker(martian.ClassGrokker):
     martian.priority(990)
     martian.component(PageTemplate)
-    martian.directive(grokcore.component.name)
+    martian.directive(grokcore.view.name)
     martian.directive(grokcore.view.view)
-    martian.directive(grokcore.component.provides, default=IPageTemplate)
+    martian.directive(grokcore.view.provides, default=IPageTemplate)
     martian.directive(grokcore.view.layer, default=IDefaultBrowserLayer)
 
     def grok(self, name, factory, module_info, **kw):
@@ -25,14 +35,6 @@ class PageTemplateGrokker(martian.ClassGrokker):
 
     def execute(self, factory, config, name, view, layer, provides, **kw):
         pagetemplate = factory()
-        templates = factory.module_info.getAnnotation('grok.templates', None)
-
-        if templates is not None:
-            config.action(
-                discriminator=None,
-                callable=self.checkTemplates,
-                args=(templates, factory.module_info, factory))
-
         adapts = (view, layer)
         config.action(
             discriminator=('adapter', adapts, provides, name),
@@ -40,14 +42,3 @@ class PageTemplateGrokker(martian.ClassGrokker):
             args=(pagetemplate, adapts, provides, name))
 
         return True
-
-    def checkTemplates(self, templates, module_info, factory):
-
-        def has_render(factory):
-            return False
-
-        def has_no_render(factory):
-            return True
-
-        templates.checkTemplates(module_info, factory, 'pagetemplate',
-                                 has_render, has_no_render)
